
/*
****** DEPRECATED

On-Screen Keyboard (<= Cinnamon 6.4)
*/

#keyboard {
  background-color: $osd_bg_color;
  border-width: 0;
  border-top-width: 1px;
  border-color: transparentize(black, 0.6);
}

.keyboard-layout {
  spacing: 10px;
  padding: 10px;
}

.keyboard-row {
  spacing: 15px;
}

.keyboard-key {
  min-height: 2em;
  min-width: 2em;
  font-size: 1.4em;
  font-weight: bold;
  border-radius: 3px;
  box-shadow: none;

  @include button(osd);

  &:hover { @include button(osd-hover); }
  &:active, &:checked { @include button(osd-active); }

  &:grayed { @include button(osd-insensitive); }
}

.keyboard-subkeys { //long press on a key popup
  color: $osd_fg_color;
  padding: 5px;
  -arrow-border-radius: 2px;
  -arrow-background-color: $osd_bg_color;
  -arrow-border-width: 1px;
  -arrow-border-color: transparentize(black, 0.6);;
  -arrow-base: 20px;
  -arrow-rise: 10px;
  -boxpointer-gap: 5px;
}

/* ****** DEPRECATED */