/* ###################################################################
 * Section common with Gnome Shell
 * ... contains a few cinnamon specific styles (rare occurences)
 * ###################################################################*/
stage {
}

.cinnamon-link {
    color: rgb(0, 0, 0);
    text-decoration: underline;
}

.cinnamon-link:hover {
    color: #50a200;
}

StScrollBar {
    padding: 0px;
}

StScrollView.vfade {
    -st-vfade-offset: 68px;
}

StScrollView StScrollBar {
    min-width: 8px;
    min-height: 8px;
    padding: 2px;
}

StScrollBar StBin#trough {
    background-color: rgba(0, 0, 0, 0);
}

StScrollBar StButton#vhandle {
    background-color: rgb(216, 216, 216);
    border: 1px solid #949494;
    border-radius: 6px;
}

StScrollBar StButton#hhandle {
    background-color: rgb(216, 216, 216);
    border: 1px solid #949494;
    border-radius: 6px;
}

StScrollBar StButton#hhandle:hover,
StScrollBar StButton#vhandle:hover {
    background-color: rgb(200, 200, 200);
    border: 1px solid #949494;
}

#Tooltip {
    border-radius: 0px;
    padding: 2px 6px;
    background-gradient-direction: vertical;
    background-gradient-start: #fbfbd7;
    background-gradient-end: #f5f5b7;
    border: 1px solid #c4c451;
    color: rgb(50, 50, 50);
    font-weight: normal;
    text-align: center;
}

.ripple-pointer-location {
  width: 50px;
  height: 50px;
  border-radius: 25px;
  background-color: rgba(172, 205, 138, 0.3);
  /*box-shadow: 0 0 2px 2px #accd8a;*/
  box-shadow: 0 0 2px 2px rgba(172, 205, 138, 1.0);
}

/* ===================================================================
 * Switches (to be used in menus)
 * ===================================================================*/
.toggle-switch {
    width: 55px;
    height: 22px;
}

.toggle-switch-us {
    border-image: url("control-assets/switch-off.svg") 4;
}

.toggle-switch-intl {
    border-image: url("control-assets/switch-off.svg") 4;
}

.toggle-switch-us:checked {
    border-image: url("control-assets/switch-on.svg") 4;
}

.toggle-switch-intl:checked {
    border-image: url("control-assets/switch-on.svg") 4;
}

/* ===================================================================
 * Shared button properties
 * ===================================================================*/
.notification-button,
.notification-icon-button {
    color: rgb(70, 70, 70);
    border-image: url("button-assets/button.png") 4;
    font-weight: normal;
    text-align: center;
}

.notification-button:hover,
.notification-icon-button:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.notification-button:focus,
.notification-icon-button:focus {
    border-image: url("button-assets/button-focus.png") 4;
}

.notification-button:active,
.notification-icon-button:active {
    border-image: url("button-assets/button-pressed.png") 4;
}

.notification-button:focus:hover,
.notification-icon-button:focus:hover,
.dialog-button:focus:hover {
    border-image: url("button-assets/button-focus-hover.png") 4;
}

.notification-button:focus:checked,
.notification-button:focus:active,
.notification-icon-button:focus:checked,
.notification-icon-button:focus:active {
    border-image: url("button-assets/button-pressed.png") 4;
}

/* ===================================================================
 * PopupMenu (popupMenu.js)
 * ===================================================================*/

.menu {
    background-color: #ececec;
    border-width: 1px;
    border-color: rgba(40, 40, 40, 0.3);
    color: rgb(70, 70, 70);
    min-width: 100px;
}

.menu.menu-top {
    border-radius: 0 0 4px 4px;
}

.menu.menu-bottom {
    border-radius: 4px 4px 0 0;
}

.menu.menu-left {
    border-radius: 0 4px 4px 0;
}

.menu.menu-right {
    border-radius: 4px 0 0 4px;
}

.menu StEntry {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry.png") 6;
    border-radius: 4px;
    width: 250px;
    min-height: 16px;
    selected-color: #fff;
    caret-color: #2b2b2b;
    caret-size: 1px;
    selection-background-color: #accd8a;
    transition-duration: 150;
}

.menu StEntry:focus {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry-focus.png") 6;
    border-radius: 4px;
    width: 250px;
    min-height: 16px;
    selected-color: #fff;
    caret-color: #2b2b2b;
    caret-size: 1px;
    selection-background-color: #accd8a;
    transition-duration: 150;
}

.popup-submenu-menu-item:open {
}

.popup-sub-menu {
    border-image: url("background-assets/sub-menu.png") 4;
    padding: 0.5em 0em;
}

.popup-sub-menu .popup-menu-item:ltr {
    padding-right: 1.75em;
}

.popup-sub-menu .popup-menu-item:rtl {
    padding-left: 1.75em;
}

.popup-sub-menu StScrollBar {
    padding: 4px;
}

.popup-sub-menu StScrollBar StBin#trough {
    background-color: rgba(0, 0, 0, 0);
}

.popup-sub-menu StScrollBar StBin#vhandle {
    background-color: rgb(216, 216, 216);
    border: 1px solid #949494;
    border-radius: 6px;
}

.popup-combo-menu {
    background-color: #ececec;
    padding: 1em 0.1em;
    color: rgb(70, 70, 70);
    border: 1px solid rgba(40, 40, 40, 0.4);
    border-radius: 4px;
}

/* The remaining popup-menu sizing is all done in ems, so that if you
 * override .popup-menu.font-size, everything else will scale with it.
 */
.popup-menu-content {
    padding: 1em 0;
}

.popup-menu-item {
    padding: .4em 1.75em;
    spacing: 1em;
}

.popup-menu-item:active {
    border-image: url("misc-assets/hover.png") 6;
    color: #fff;
}

.popup-menu-item:insensitive {
    color: rgb(140, 140, 140);
}

.popup-combobox-item {
    spacing: 1em;
}

.popup-separator-menu-item {
    -gradient-height: 1px;
    -gradient-start: rgb(210, 210, 210);
    -gradient-end: rgb(210, 210, 210);
    -margin-horizontal: 0;
    height: 1px;
}

.popup-alternating-menu-item:alternate {
    font-weight: bold;
    color: rgb(70, 70, 70);
}

.popup-slider-menu-item {
    border-image: url("misc-assets/slider.png") 10 10 9 9 stretch;
    height: 18px;
    min-width: 15em;
    -slider-height: 4px;
    -slider-background-color: rgba(0, 0, 0, 0);
    -slider-border-color: rgba(0, 0, 0, 0);
    -slider-active-background-color: #accd8a;
    -slider-active-border-color: rgba(0, 0, 0, 0);
    -slider-border-width: 1px;
    -slider-handle-radius: 6px;
}

.popup-device-menu-item {
    spacing: .5em;
}

.popup-inactive-menu-item {
    font-weight: bold;
    color: #797979;
}

.popup-subtitle-menu-item {
    font-weight: bold;
    color: rgb(70, 70, 70);
}

.popup-menu-icon {
    icon-size: 1em;
}

.nm-menu-item-icons {
    spacing: .5em;
}

/* ===================================================================
 * Panel (panel.js)
 * ===================================================================*/
#panel {
    color: #000;
    height: 26px;
    width: 32px;
    padding: 0px;
}

#panel:highlight {
    background-color: #accd8a;
}

.panel-dummy {
    border: 1px solid rgba(172, 205, 138, 1.0);
    background-color: rgba(172, 205, 138, 0.6);
}

.panel-dummy:entered {
    background-color: rgba(172, 205, 138, 0.9);
}

#panelLeft,
#panelCenter {
    spacing: 4px;
}

.panel-left #panelLeft,
.panel-left #panelRight,
.panel-left #panelCenter,
.panel-right #panelLeft,
.panel-right #panelRight,
.panel-right #panelCenter {
    spacing: 0;
}

#panelLeft:dnd {
    background-color: rgba(255, 0, 0, 0.1);
}

#panelCenter:dnd {
    background-color: rgba(0, 255, 0, 0.1);
}

#panelRight:dnd {
    background-color: rgba(0, 0, 255, 0.1);
}

#panelLeft:ltr {
    padding-right: 4px;
}

#panelLeft:rtl {
    padding-left: 4px;
}

#panelRight:ltr {
    padding-left: 0px;
    spacing: 0px;
}

#panelRight:rtl {
    padding-right: 0px;
    spacing: 0px;
}

#panelLeft.vertical:ltr {
    padding-right: 0px;
}

#panelLeft.vertical:rtl {
    padding-left: 0px;
}

.panel-top,
.panel-bottom {
    background-gradient-direction: vertical;
    background-gradient-start: rgb(246, 246, 246);
    background-gradient-end: rgb(206, 206, 206);
    box-shadow: 0px 0px 1px 1px rgba(40, 40, 40, 0.4);
}

.panel-left,
.panel-right {
    background-gradient-direction: horizontal;
    background-gradient-start: rgb(246, 246, 246);
    background-gradient-end: rgb(206, 206, 206);
    box-shadow: 0px 0px 1px 1px rgba(40, 40, 40, 0.4);
}

.system-status-icon {
    padding-left: 0px;
    padding-right: 0px;
    spacing: 0px;
    margin: 0px;
}

.system-status-icon.warning {
    color: #d2aa1e;
}

.system-status-icon.error {
    color: #d54444;
}

#appMenu {
    spacing: 4px;
}

.popup-menu-item-dot {
}

.system-status-icon {
    icon-size: 1.14em;
}

/* ===================================================================
 * Overview (workspace.js)
 * ===================================================================*/
#overview {
    spacing: 12px;
}

.workspace-thumbnails {
    spacing: 26px;
    padding-left: 0.9em;
    padding-right: 1em;
}

.workspace-add-button {
    background-image: url("misc-assets/plus.png");
    height: 200px;
    width: 35px;
    transition-duration: 100;
}

.workspace-add-button:hover {
    background-image: url("misc-assets/plus-hover.png");
    transition-duration: 100;
}

.workspace-close-button {
    background-image: url("control-assets/close.svg");
    height: 35px;
    width: 35px;
    -cinnamon-close-overlap: 25px;
    transition-duration: 150;
}

.workspace-close-button:hover {
    background-image: url("control-assets/close-hover.svg");
    transition-duration: 150;
}

.window-border {
    border: 3px #accd8a;
    border-radius: 4px;
    background-color: rgba(255,255,255,.05);
    /* Cover rounded corners and some bad adjustment gaps */
    box-shadow: 0 0 0 1px #accd8a inset;
}

.window-caption {
    border-image: url("background-assets/bg-1.png") 6;
    font-weight: bold;
    padding: 6px 8px;
    spacing: 8px;
    color: rgb(70, 70, 70);
    -cinnamon-caption-spacing: 10px;
}

.window-caption:focus {
    border-image: url("background-assets/bg-2.png") 6;
    color: #fff;
}

.window-close {
    background-image: url("control-assets/close.svg");
    height: 35px;
    width: 35px;
    -cinnamon-close-overlap: 16px;
    transition-duration: 150;
}

.window-close:hover {
    background-image: url("control-assets/close-hover.svg");
    transition-duration: 150;
}

.window-close-area {
    background-image: url("misc-assets/trash.png");
    height: 150px;
    width: 226px;
}

.expo-background {
    background: url("background-assets/noise-texture-2.png");
    background-repeat: repeat;
    background-gradient-direction: radial;
    background-gradient-start: #4f4f4f;
    background-gradient-end: #363636;
}

.workspace-overview-background-shade {
    background-color: rgba(0, 0, 0, .4);
}

.overview-empty-placeholder {
    color: #ffffff;
    font-size: 2em;
}

.expo-workspace-thumbnail-frame {
    border: 11px transparent;
    border-image: url("misc-assets/workspace-shadow.png") 14;
}

.expo-workspace-thumbnail-frame#active {
    border: 11px transparent;
    border-image: url("misc-assets/workspace-shadow.png") 14;
}

.applet-cornerbar {
  width: 8px;
  background-color: rgba(0, 0, 0, 0.2);
}

.applet-cornerbar-box {
  padding: 4px 4px;
}

.applet-cornerbar-box:hover {
  background-color: #c0c0c0;
}

.applet-cornerbar.vertical {
  height: 8px;
}

/* ===================================================================
* Desklets (desklet.js)
* ===================================================================*/
.desklet {
    color: rgb(70, 70, 70);
}

.desklet:highlight,
.desklet-with-borders:highlight,
.desklet-with-borders-and-header:highlight {
    background-color: #accd8a;
}

.desklet-with-borders {
    border-image: url("background-assets/bg-1.png") 6;
    color: rgb(70, 70, 70);
    font-weight: bold;
    padding: 8px;
}

.desklet-with-borders-and-header {
    border-image: url("background-assets/desklet.png") 6;
    color: rgb(70, 70, 70);
    padding: 8px;
}

.desklet-header {
    border-image: url("background-assets/header.png") 8;
    font-weight: bold;
    text-shadow: #eee 0px 0px 0px;
    color: rgb(70, 70, 70);
    padding: 8px;
}

.desklet-drag-placeholder {
    border: 0px solid #ccc;
    border-radius: 0px;
    background: none;
}

.xkcd-box {
    padding: 6px;
    border: 0px solid #141414;
    background-color: rgba(0, 0, 0, 0);
    border-radius: 0px;
}

.photoframe-box {
    padding: 10px;
    border-image: url("background-assets/bg-1.png") 6;
}

/* ===================================================================
 * Clock Desklet (clock@cinnamon.org/desklet.js)
 * ===================================================================*/
.clock-desklet-label {
    color: rgb(70, 70, 70);
}

/* ===================================================================
 * Looking Glass (lookingGlass.js)
 * ===================================================================*/
#LookingGlassDialog {
    border-image: url("background-assets/bg-1.png") 6;
    transition-duration: 300;
    padding-left: 8px;
    padding-right: 8px;
    padding-top: 8px;
    padding-bottom: 8px;
    color: rgb(70, 70, 70);
}

/* ===================================================================
 * Date applet (calendar@cinnamon.org/calendar.js)
 * ===================================================================*/
.calendar {
    /*margin-bottom: .5em;*/
    /*margin: 0 1.0em 0 0.5em;*/
    spacing-rows: 0;
    spacing-columns: 0;
}

.calendar-main-box {
}

.calendar-events-main-box {
  height: 300px;
  min-width: 350px;
  background-color: rgb(236, 236, 236);
  border: 1px solid rgb(192, 192, 192);
  border-radius: 4px;
  margin-bottom: .5em;
  margin-right: 0.75em;
  padding: .5em;
}

.calendar-events-no-events-box {
}

.calendar-events-no-events-button {
    border-image: url("button-assets/button.png") 4;
    margin: 6px 0 6px 0;
    padding: 6px;
}

.calendar-events-no-events-button:hover:active {
    border-image: url("button-assets/button-pressed.png") 4;
}

.calendar-events-no-events-button:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.calendar-events-no-events-icon {
    color: rgba(0, 0, 0, 0.7);
}

.calendar-events-no-events-label {
    font-weight: bold;
    text-align: center;
}

.calendar-events-date-label {
  padding: .1em .1em .5em .1em;
  font-weight: bold;
  text-align: center;
}

.calendar-events-main-box .separator {
    background: unset;
}

.calendar-events-event-container {
    padding:  0;
}

.calendar-event-button {
    margin: 2px 2px 2px 2px;
    border: 1px solid rgba(0, 0, 0, 0);
}

.calendar-event-button:hover {
    color: #fff;
    border-image: url("misc-assets/hover-2.png") 6;
}

.calendar-event-row-content {
    margin: 2px 7px 2px 7px;
}

.calendar-event-time-past {
    color: rgba(0, 0, 0, 0.27);
    font-weight: bold;
    text-align: left;
    margin-bottom: .2em;
}
.calendar-event-time-present {
    font-weight: bold;
    text-align: left;
    margin-bottom: .2em;
}

.calendar-event-time-present:all-day {
    color: #accd8a;
}

.calendar-event-time-future {
    color: rgba(0, 0, 0, 0.87);
    font-weight: bold;
    text-align: left;
    margin-bottom: .2em;
}

.calendar-event-summary {
    color: rgba(0, 0, 0, 0.87);
    text-align: left;
    width: 200px;
    padding-bottom: 2px;
}

.calendar-event-countdown {
    text-align: right;
    margin-bottom: .6em;
}

.calendar-event-countdown:soon {
      font-weight: bold;
}

.calendar-event-countdown:imminent {
      font-weight: bold;
      color: #d2aa1e;
}

.calendar-event-countdown:current {
      font-weight: bold;
      color: #accd8a;
}

.calendar-event-button:hover .calendar-event-time-past,
.calendar-event-button:hover .calendar-event-time-present,
.calendar-event-button:hover .calendar-event-time-future,
.calendar-event-button:hover .calendar-event-summary,
.calendar-event-button:hover .calendar-event-countdown,
.calendar-event-button:hover .calendar-event-countdown:soon,
.calendar-event-button:hover .calendar-event-countdown:imminent,
.calendar-event-button:hover .calendar-event-countdown:current {
    color: #ffffff;
}

.calendar-event-color-strip {
  width: 4px;
  border-width: 1px;
  border-radius: 2px 0 0 2px;
}

.datemenu-date-label {
    padding: .5em 0em 1em 0em;
    font-weight: bold;
    text-align: center;
}

.calendar-month-label {
    padding-bottom: 3px;
    padding-top: 3px;
    font-weight: bold;
}

.calendar-change-month-back,
.calendar-change-month-forward:rtl {
    height: 20px;
    width: 20px;
    transition-duration: 200;
    border: 1px rgba(0, 0, 0, 0);
    background-image: url("control-assets/calendar-arrow-left.svg");
}

.calendar-change-month-back:hover {
    transition-duration: 150;
    background-image: url("control-assets/calendar-arrow-left-hover.svg");
}

.calendar-change-month-forward,
.calendar-change-month-back:rtl {
    height: 20px;
    width: 20px;
    transition-duration: 200;
    border: 1px rgba(0, 0, 0, 0);
    background-image: url("control-assets/calendar-arrow-right.svg");
}

.calendar-change-month-forward:hover {
    transition-duration: 150;
    background-image: url("control-assets/calendar-arrow-right-hover.svg");
}

.calendar-today-home-button {
    padding: 7px;
}

.calendar-today-home-button-enabled {
    border-image: url("button-assets/button.png") 4;
    padding: 7px;
}

.calendar-today-home-button-enabled:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.calendar-today-day-label {
    font-size: 1.75em;
    font-weight: bold;
    text-align: center;
    padding-bottom: .1em;
}

.calendar-today-date-label {
    font-size: 1.1em;
    font-weight: bold;
    text-align: center;
}

.calendar-day-event-dot-box {
  margin-top: 1.7em;
  max-rows: 1; }

.calendar-day-event-dot {
  margin: 1px;
  border-radius: 2px;
  width: 4px;
  height: 4px; }

.calendar-day-base {
    font-size: 0.9em;
    text-align: center;
    width: 2.4em;
    height: 2.4em;
}

.calendar-day-base:hover {
    color: rgba(0, 0, 0, 0.7);
    background: rgba(172, 205, 138, 0.3);
    font-weight: bold;
}

.calendar-day-heading {
    font-size: 0.9em;
    color: #323232;
    padding-top: 1em;
}

.calendar-week-number {
    color: rgba(0, 0, 0, 0.5);
    font-size: 0.9em;
}

.calendar-day {
    border: 1px rgba(0, 0, 0, 0.2);
    color: rgba(0, 0, 0, 0.7);
    border-top-width: 0;
    border-left-width: 0;
    padding-left: 1px;
    padding-top: 1px;
    background-color: rgba(255, 255, 255, 0.1);
}

.calendar-day-top {
    border-top-width: 1px;
}

.calendar-day-left {
    border-left-width: 1px;
}

.calendar-work-day {
}

.calendar-nonwork-day {
    background-color: rgba(128, 128, 128, 0.1);
}

.calendar-today {
    background: rgba(172, 205, 138, 0.3);
}

.calendar-today:selected {
    font-weight: bold;
}

.calendar-not-today:selected {
    font-weight: bold;
    background-color: rgba(128, 128, 128, 0.3);
}
.calendar-not-today:selected:hover {
    color: rgba(0, 0, 0, 0.7);
}

.calendar-other-month-day {
    color: rgba(50, 50, 50, 0.3);
    box-shadow: inset 0px 2px 3px 0px rgba(0, 0, 0, 0.1);
    background-color: rgba(50, 50, 50, 0.1);
}

/* ===================================================================
 * Notifications (messageTray.js)
 * ===================================================================*/
#notification {
    border-image: url("background-assets/bg-1.png") 6;
    padding: 8px 8px 8px 8px;
    spacing-rows: 10px;
    spacing-columns: 10px;
    margin-from-right-edge-of-screen: 20px;
    width: 34em;
    color: rgb(70, 70, 70);
}

#notification.multi-line-notification {
    padding-bottom: 8px;
    color: rgb(70, 70, 70);
}

/* We use row-span = 2 for the image cell, which prevents its height preferences to be
   taken into account during allocation, so its height ends up being limited by the height
   of the content in the other rows. To avoid showing a stretched image, we set the minimum
   height of the table to be ICON_SIZE + IMAGE_SIZE + spacing-rows = 24 + 125 + 10 = 159 */
.notification-with-image {
    min-height: 159px;
    color: rgb(70, 70, 70);
}

#notification-scrollview {
    max-height: 100em;
}

#notification-scrollview > .top-shadow,
#notification-scrollview > .bottom-shadow {
    height: 10em;
}

#notification-scrollview:ltr > StScrollBar {
    padding-left: 6px;
}

#notification-scrollview:rtl > StScrollBar {
    padding-right: 6px;
}

#notification-body {
    spacing: 5px;
}

#notification-actions {
    spacing: 10px;
}

.notification-button {
    border-image: url("button-assets/button.png") 4;
    border-radius: 18px;
    min-width: 5em;
    padding: 5px;
}

.notification-button:focus {
    padding: 4px;
}

#notification .cinnamon-link {
    color: rgb(0, 0, 0);
    text-decoration: underline;
}

.notification-icon-button {
    border-image: url("button-assets/button.png") 4;
    border-radius: 0px;
    padding: 5px;
}

.notification-icon-button:focus {
    padding: 4px;
}

.notification-icon-button > StIcon {
    icon-size: 36px;
}

#notification StEntry {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry.png") 6;
    border-radius: 4px;
    caret-color: #2b2b2b;
    caret-size: 1px;
    width: 250px;
    height: 16px;
    transition-duration: 300;
    selected-color: #fff;
    selection-background-color: #accd8a;
}

#notification StEntry:focus {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry-focus.png") 6;
    border-radius: 4px;
    width: 250px;
    height: 16px;
    selected-color: #fff;
    caret-color: #2b2b2b;
    caret-size: 1px;
    selection-background-color: #accd8a;
    transition-duration: 150;
}

/* For the links inside notifications.
   These URLs are already underlined with Pango markup. */
#notification .url-highlighter {
    link-color: #50a200;
}

/* ===================================================================
 * Alt Tab (appSwitcher/classicSwitcher.js)
 * ===================================================================*/
#altTabPopup {
    padding: 8px;
    spacing: 16px;
}

.switcher-list {
    border-image: url("background-assets/bg-1.png") 6;
    color: rgb(70, 70, 70);
    padding: 20px;
    font-size: 0.9em;
    font-weight: bold;
}

.switcher-list-item-container {
    spacing: 8px;
}

.thumbnail-scroll-gradient-left {
    background-color: rgba(51, 51, 51, 0.5);
    border-radius: 24px;
    border-radius-topright: 0px;
    border-radius-bottomright: 0px;
    width: 60px;
}

.thumbnail-scroll-gradient-right {
    background-color: rgba(51, 51, 51, 0.5);
    border-radius: 24px;
    border-radius-topleft: 0px;
    border-radius-bottomleft: 0px;
    width: 60px;
}

.switcher-list .item-box {
    padding: 8px;
    border: 1px solid rgba(0, 0, 0, 0);
    border-radius: 0px;
}

.switcher-list .item-box:outlined {
    padding: 6px;
    border: 2px solid rgba(85, 85, 85, 0);
}

.switcher-list .item-box:selected {
    border-image: url("misc-assets/hover-2.png") 6;
    color: #fff;
}

.switcher-list .thumbnail-box {
    padding: 2px;
    spacing: 4px;
}

.switcher-list .thumbnail {
    width: 256px;
}

.switcher-list .separator {
    width: 1px;
    background: rgba(255, 255, 255, 0.33);
}

.ripple-box {
    width: 104px;
    height: 104px;
    background-image: url("misc-assets/corner-ripple.png");
}

.ripple-box:rtl {
    background-image: url("misc-assets/corner-ripple.png");
}

.switcher-arrow {
    border-color: rgba(0, 0, 0, 0);
    color: #dcdcdc;
}

.switcher-arrow:highlighted {
    border-color: rgba(0, 0, 0, 0);
    color: white;
}

.switcher-preview-backdrop {
    background-color: rgba(25, 25, 25, 0.65);
}

/* ===================================================================
 * dialogs (dialog.js)
 * ===================================================================*/
.dialog {
    border-image: url("background-assets/bg-1.png") 6;
    color: rgb(70, 70, 70);
    padding: 20px;
}

.dialog-button-box {
}

.dialog-button {
    height: 22px;
    color: rgb(70, 70, 70);
    border-image: url("button-assets/button.png") 4;
    padding: 3px 31px 4px;
}

.dialog-button:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.dialog-button:focus {
    border-image: url("button-assets/button-focus.png") 4;
    padding: 3px 31px 4px;
}

.dialog-button:active,
.dialog-button:checked {
    border-image: url("button-assets/button-pressed.png") 4;
}

.dialog-button:focus:hover {
    border-image: url("button-assets/button-focus-hover.png") 4;
    padding: 3px 31px 4px;
}

.dialog-button:focus:checked,
.dialog-button:focus:active {
    border-image: url("button-assets/button-pressed.png") 4;
}

.dialog-button:disabled {
    color: #a6a6a6;
}

.dialog-button:destructive-action {
    color: white;
    border-width: 1px;
    border-color: rgba(40, 40, 40, 0.4);
    border-image: none;
    border-radius: 4px;
    padding: 2px 31px 5px;
    background-gradient-direction: vertical;
	background-gradient-start: #e83c44;
	background-gradient-end: #ce1921;
}

.dialog-button:focus:destructive-action {
    color: white;
    border-width: 1px;
    border-color: rgba(172, 205, 138, 0.4);
    border-image: none;
    border-radius: 4px;
    padding: 2px 31px 5px;
    background-gradient-direction: vertical;
	background-gradient-start: #e83c44;
	background-gradient-end: #ce1921;
}

.dialog-button:hover:destructive-action {
    background-gradient-direction: vertical;
	background-gradient-start: #ee4a52;
	background-gradient-end: #e22831;
}

.dialog-button:focus:hover:destructive-action {
    color: white;
    border-width: 1px;
    border-color: rgba(172, 205, 138, 0.4);
    border-image: none;
    border-radius: 4px;
    padding: 2px 31px 5px;
    background-gradient-direction: vertical;
	background-gradient-start: #ee4a52;
	background-gradient-end: #e22831;
}

.dialog-button:active:destructive-action,
.dialog-button:checked:destructive-action,
.dialog-button:focus:checked:destructive-action,
.dialog-button:focus:active:destructive-action {
    background-gradient-direction: vertical;
	background-gradient-start: #b21811;
	background-gradient-end: #be2a32;
}

.dialog-list .dialog-list-title {
    padding: 1.3em;
    text-align: center;
    color: rgb(70, 70, 70);
}

.dialog-list-item .dialog-list-item-description {
    color: rgb(70, 70, 70);
}


/* =============================================================================
 * CinnamonMountOperation Dialogs (cinnamonMountOperation.js)
 * ============================================================================= */

.cinnamon-mount-operation-icon {
    icon-size: 48px;
}

.mount-password-reask {
    color: red;
}

.show-processes-dialog,
.mount-question-dialog {
    spacing: 24px;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject {
    font-weight: bold;
    color: rgb(70, 70, 70);
    padding-top: 10px;
    padding-left: 17px;
    padding-bottom: 6px;
}

.show-processes-dialog-subject:rtl,
.mount-question-dialog-subject:rtl {
    padding-left: 0px;
    padding-right: 17px;
}

.show-processes-dialog-description,
.mount-question-dialog-description {
    color: rgb(70, 70, 70);
    padding-left: 17px;
    width: 28em;
}

.show-processes-dialog-description:rtl,
.mount-question-dialog-description:rtl {
    padding-right: 17px;
}

.show-processes-dialog-app-list {
    max-height: 200px;
    padding-top: 24px;
    padding-left: 49px;
    padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
    padding-right: 49px;
    padding-left: 32px;
}

.show-processes-dialog-app-list-item {
    color: rgb(70, 70, 70);
}

.show-processes-dialog-app-list-item:hover {
    color: rgb(120, 120, 120);
}

.show-processes-dialog-app-list-item:ltr {
    padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
    padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
    padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
    padding-left: 17px;
}

.show-processes-dialog-app-list-item-name {
}

/* ===================================================================
 * Magnifier (magnifier.js)
 * ===================================================================*/
.magnifier-zoom-region {
    border: 2px solid rgba(128, 0, 0, 1);
}

.magnifier-zoom-region.full-screen {
    border-width: 0px;
}

/* ===================================================================
 * On screen keyboard (keyboard.js) ********** DEPRECATED 6.6
 * ===================================================================*/
#keyboard {
    border-image: url("background-assets/keyboard-bg.png") 4;
}

.keyboard-layout {
    spacing: 10px;
    padding: 10px;
}

.keyboard-row {
    spacing: 15px;
}

.keyboard-key {
    min-height: 30px;
    min-width: 30px;
    border-image: url("button-assets/button.png") 4;
    font-size: 1.4em;
    font-weight: bold;
    color: rgb(70, 70, 70);
}

.keyboard-key:grayed {
    color: #888;
    border-image: url("button-assets/button.png") 4;
}

.keyboard-key:checked,
.keyboard-key:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.keyboard-key:active {
    border-image: url("button-assets/button-pressed.png") 4;
}

.keyboard-subkeys {
    color: rgb(70, 70, 70);
    padding: 5px;
    -arrow-border-radius: 4px;
    -arrow-background-color: rgb(225, 225, 225);
    -arrow-border-width: 1px;
    -arrow-border-color: rgba(40, 40, 40, 0.4);
    -arrow-base: 18px;
    -arrow-rise: 10px;
    -st-shadow: 0px -1px 2px 0px rgba(255, 255, 255, 0.9);
    -boxpointer-gap: 2px;
}

/* ======================================
 * On-Screen Keyboard (>= Cinnamon 6.6)
 * ======================================*/
/*
On-Screen Keyboard (>= Cinnamon 6.6)
*/
#virtual-keyboard {
  border-image: url("background-assets/keyboard-bg.png") 4;
}

.vkeyboard-key-container {
  padding: 3px;
  spacing: 3px; }

.vkeyboard-key {
    border-image: url("button-assets/button.png") 4;
    font-size: 1.4em;
    font-weight: bold;
    padding: 4px 4px 4px;
    color: rgb(70, 70, 70);
}

.vkeyboard-key StIcon {
    icon-size: 1.125em;
}

.vkeyboard-key:checked,
.vkeyboard-key:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.vkeyboard-key:active,
.vkeyboard-key.modifier-key:latched,
.vkeyboard-key.modifier-key:latched:hover,
.vkeyboard-key.shift-key-uppercase {
    border-image: url("button-assets/button-pressed.png") 4;
}

.vkeyboard-key.shift-key-lowercase,
.vkeyboard-key.escape-key,
.vkeyboard-key.hide-key,
.vkeyboard-key.enter-key,
.vkeyboard-key.modifier-key,
.vkeyboard-key.non-alpha-key {
    border-image: url("button-assets/button-darker.png") 4;
}

.vkeyboard-key.enter-key:hover,
.vkeyboard-key.enter-key:checked,
.vkeyboard-key.shift-key-lowercase:hover,
.vkeyboard-key.shift-key-lowercase:checked,
.vkeyboard-key.escape-key:hover,
.vkeyboard-key.escape-key:checked,
.vkeyboard-key.hide-key:hover,
.vkeyboard-key.hide-key:checked,
.vkeyboard-key.modifier-key:hover,
.vkeyboard-key.modifier-key:checked,
.vkeyboard-key.non-alpha-key:hover,
.vkeyboard-key.non-alpha-key:checked {
    border-image: url("button-assets/button-hover.png") 4;
}

.vkeyboard-key.enter-key:active,
.vkeyboard-key.shift-key-lowercase:active,
.vkeyboard-key.escape-key:active,
.vkeyboard-key.hide-key:active,
.vkeyboard-key.modifier-key:active,
.vkeyboard-key.non-alpha-key:active {
    border-image: url("button-assets/button-pressed.png") 4;
}

.vkeyboard-subkeys {
    color: rgb(70, 70, 70);
    padding: 7px;
    -arrow-border-radius: 4px;
    -arrow-background-color: rgb(225, 225, 225);
    -arrow-border-width: 1px;
    -arrow-border-color: rgba(40, 40, 40, 0.4);
    -arrow-base: 18px;
    -arrow-rise: 10px;
    -st-shadow: 0px -1px 2px 0px rgba(255, 255, 255, 0.9);
    -boxpointer-gap: 2px;
}

.word-suggestions {
  font-size: 1.227em;
  spacing: 20px;
  min-height: 20pt; }

.candidate-popup-boxpointer {
  -arrow-border-radius: 4px;
  -arrow-background-color: #ebebed;
  -arrow-border-color: rgba(40, 40, 40, 0.4);
  -arrow-border-width: 1px;
  -arrow-base: 12px;
  -arrow-rise: 4px;
  -arrow-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.5); }

.candidate-popup-content {
  border-image: url("background-assets/bg-1.png") 4;
  padding: 0.5em;
  spacing: 0.6em; }

.candidate-index {
  padding: 0 0.5em 0 0;
  color: #171717; }

.candidate-box {
    padding: 4px;

    border-radius: 4px;
    color: black;
}
.candidate-box:selected, .candidate-box:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.candidate-page-button-box {
  height: 2em;
  spacing: .6em;
}

.vertical .candidate-page-button-box {
    padding-top: 0.5em;
}

.horizontal .candidate-page-button-box {
    padding-left: 0.5em;
}

.candidate-page-button {
  border-image: url("button-assets/button-hover.png") 4;
  padding: 4px 8px;
}

.candidate-page-button-previous {
  border-radius: 6px 0px 0px 6px;
  border-right-width: 0; }

.candidate-page-button-next {
  border-radius: 0px 6px 6px 0px; }

.candidate-page-button-icon {
  icon-size: 1em; }


/* ===================================================================
 * Policykit authentication dialog
 * ===================================================================*/

.prompt-dialog {
    /* this is the width of the entire modal popup */
    width: 400px;
}

.polkit-dialog-user-layout {
    spacing: 10px;
}

.polkit-dialog-user-combo {
    border-image: url("button-assets/button.png") 4;
    padding: 0.5em 2em;
    color: rgb(70, 70, 70);
}

.polkit-dialog-user-combo:hover {
    border-image: url("button-assets/button-hover.png") 4;
}

.polkit-dialog-user-combo:focus {
    border-image: url("button-assets/button-focus.png") 4;
}

.polkit-dialog-user-combo:active,
.polkit-dialog-user-combo:checked {
    border-image: url("button-assets/button-pressed.png") 4;
}

.polkit-dialog-user-combo:focus:hover {
    border-image: url("button-assets/button-focus-hover.png") 4;
}

.polkit-dialog-user-combo:focus:checked,
.polkit-dialog-user-combo:active {
    border-image: url("button-assets/button-pressed.png") 4;
}

.polkit-dialog-user-combo:disabled,
.polkit-dialog-user-combo:insensitive {
    color: #a6a6a6;
}

.prompt-dialog-password-entry {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry.png") 6;
    border-radius: 4px;
    caret-color: #2b2b2b;
    caret-size: 1px;
    width: 250px;
    transition-duration: 300;
    selected-color: #fff;
    selection-background-color: #accd8a;
}

.prompt-dialog-password-entry:focus {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry-focus.png") 6;
    border-radius: 4px;
    width: 250px;
    selected-color: #fff;
    caret-color: #2b2b2b;
    caret-size: 1px;
    selection-background-color: #accd8a;
    transition-duration: 150;
}

.prompt-dialog-password-entry .capslock-warning {
    icon-size: 16px;
    warning-color: rgb(64, 64, 64);
    padding: 0 4px;
}

.prompt-dialog-error-label {
    text-align: center;
    font-size: 1em;
    color: #ff0000;
}

.prompt-dialog-info-label {
    font-size: 1em;
}

.prompt-dialog-password-entry StLabel.hint-text {
    color: rgba(70, 70, 70, 0.4);
}

.prompt-dialog-password-entry StIcon.peek-password {
    icon-size: 16px;
    color: rgb(70, 70, 70);
}

/* ===================================================================
 * Run dialog
 * ===================================================================*/

.run-dialog-description {
    text-align: center;
    color: rgb(70, 70, 70);
}
 
.run-dialog-entry {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry.png") 6;
    border-radius: 4px;
    width: 250px;
    min-height: 16px;
    selected-color: #fff;
    caret-color: #2b2b2b;
    caret-size: 1px;
    selection-background-color: #accd8a;
    transition-duration: 150;
}

.run-dialog-entry:focus {
    padding: 4px 12px;
    color: #2b2b2b;
    border-image: url("misc-assets/entry-focus.png") 6;
    border-radius: 4px;
    width: 250px;
    min-height: 16px;
    selected-color: #fff;
    caret-color: #2b2b2b;
    caret-size: 1px;
    selection-background-color: #accd8a;
    transition-duration: 150;
}

/* ###################################################################
 * Audio device selection dialog
 * ###################################################################*/

.audio-device-selection-dialog .audio-selection-box .audio-selection-device {
    border-image: url("button-assets/button.png") 4;
    color: rgb(70, 70, 70);
}
.audio-device-selection-dialog .audio-selection-box .audio-selection-device:focus {
    border-image: url("button-assets/button-focus.png") 4;
}
.audio-device-selection-dialog .audio-selection-box .audio-selection-device:hover {
    border-image: url("button-assets/button-hover.png") 4;
}
.audio-device-selection-dialog .audio-selection-box .audio-selection-device:insensitive {
    color: #a6a6a6
}
.audio-device-selection-dialog .audio-selection-box .audio-selection-device:selected,
.audio-device-selection-dialog .audio-selection-box .audio-selection-device:active,
.audio-device-selection-dialog .audio-selection-box .audio-selection-device:checked {
    border-image: url("button-assets/button-pressed.png") 4;
}

/* ###################################################################
 * Cinnamon Specific Section
 * ###################################################################*/

/* ===================================================================
 * Menu applet (menu@cinnamon.org/applet.js)
 * Deprecated since Cinnamon 6.6. Kept here temporarily to support
 * spices and old Cinnamon versions.
 * ===================================================================*/

/* Main menu title */

.menu-favorites-box {
    background-color: rgb(236, 236, 236);
    border: 1px solid rgb(192, 192, 192);
    border-radius: 4px;
    padding: 0.5em;
}

.menu-favorites-button {
    padding: .9em 1em;
    border-radius: 2px;
}

.menu-favorites-button:hover {
    border-image: url("misc-assets/hover-2.png") 6;
}

.menu-categories-box {
    padding-top: 10px;
    padding-left: 30px;
    padding-right: 30px;
    padding-bottom: 10px;
}

.menu-applications-outer-box {
    padding: 0px 10px;
}

.menu-applications-inner-box {
    margin-top: 10px;
    margin-left: 10px;
    margin-right: 10px;
    margin-bottom: 0px;
}

.menu-application-button {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    max-width: 10px;
}

.menu-application-button:highlighted {

    /* This style is used in menu application buttons for applications which were newly installed */
    font-weight: bold;
}

.menu-application-button-selected {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    color: #fff;
    border-image: url("misc-assets/hover-2.png") 6;
}

.menu-application-button-selected:highlighted {

    /* This style is used in menu application buttons for applications which were newly installed */
    font-weight: bold;
}

.menu-application-button-label:ltr {
    padding-left: 5px;
}

.menu-application-button-label:rtl {
    padding-right: 5px;
}

.menu-category-button {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
}

.menu-category-button-greyed {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    color: rgba(100, 100, 100, 1);
    font-style: italic;
}

.menu-category-button-selected {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    color: #fff;
    border-image: url("misc-assets/hover-2.png") 6;
}

.menu-category-button-label:ltr {
    padding-left: 5px;
}

.menu-category-button-label:rtl {
    padding-right: 5px;
}

/* Name and description of the currently hovered item in the menu
 * This appears on the bottom right hand corner of the menu*/
.menu-selected-app-box {
    padding-right: 30px;
    padding-left: 28px;
    text-align: right;
}

.menu-selected-app-title {
    font-weight: bold;
}

.menu-selected-app-description {
    max-width: 150px;
}

.menu-search-box {
    padding-left: 30px;
}

.menu-search-entry-icon {
    icon-size: 1em;
    color: #2b2b2b;
}

.menu-context-menu {
}

#menu-search-entry StLabel.hint-text {
    color: rgba(70, 70, 70, 0.3);
}

/* ===================================================================
 *  New Menu applet (menu@cinnamon.org/applet.js)
 *  Since Cinnamon 6.6
 * ===================================================================*/

.appmenu-background .popup-menu-content {
  padding: 0;
}

.appmenu-main-box {
  spacing: 10px;
}

.appmenu-right-box {
  spacing: 5px;
  padding: 10px 10px;
}

.appmenu-search-box {
    spacing: 10px;
}

.appmenu-categories-applications-box {
  spacing: 15px;
  padding: 10px 10px;
}

.appmenu-categories-applications-box:top {
  /* Extra padding at the top of the categories/apps
   when the search box is at the bottom */
  padding-top: 5px;
}

.appmenu-applications-box {
  /* Extra gap between the highlighted app and the scroll handle */
  padding-right: 5px;
}

.appmenu-system-box {
  spacing: 10px;
}

.appmenu-sidebar {
    padding: 10px 0px;
    spacing: 5px;
    background-color: #dadada;
    border: 1px solid rgb(192, 192, 192);
    border-radius: 4px 0 0 4px;
    border-right-width: 1px;
}

.appmenu-sidebar .appmenu-system-button-lock:hover {
  background-color: #444444;
  color: white;
}

.appmenu-sidebar .appmenu-system-button-logout:hover {
  background-color: #444444;
  color: white;
}

.appmenu-application-button-label:ltr {
    padding-left: 5px;
}

.appmenu-application-button-label:rtl {
    padding-right: 5px;
}

.appmenu-application-button-description {
    font-size: 0.9em;
    color: rgb(110, 110, 110);
}

.appmenu-application-button-description:ltr {
    padding-left: 5px;
}

.appmenu-application-button-description:rtl {
    padding-right: 5px;
}

.appmenu-sidebar-button {
    padding: 4px 1em;
}

.appmenu-sidebar-button:hover {
    background-color: #c0c0c0;
    border-radius: 4px;
}

.appmenu-system-button {
  padding: 8px;
  border-radius: 9999px;
}

.appmenu-system-button-lock:hover {
  background-color: #444444;
  color: white;
}

.appmenu-system-button-logout:hover {
  background-color: #444444;
  color: white;
}

.appmenu-system-button-shutdown:hover {
  background-color: #c21616;
  color: white;
}

.appmenu-application-button {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    max-width: 10px;
}

.appmenu-application-button:highlighted {
    /* This style is used in menu application buttons for applications which were newly installed */
    font-weight: bold;
}

.appmenu-application-button-selected {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    border-radius: 4px;
    max-width: 10px;
    background-color: #dadada;
}

.appmenu-application-button-selected:highlighted {
    /* This style is used in menu application buttons for applications which were newly installed */
    font-weight: bold;
}

.appmenu-category-button {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
}

.appmenu-category-button-greyed {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    color: rgba(100, 100, 100, 1);
    font-style: italic;
}

.appmenu-category-button-selected {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    background-color: #dadada;
    border-radius: 4px;
}

.appmenu-category-button-label:ltr {
    padding-left: 5px;
}

.appmenu-category-button-label:rtl {
    padding-right: 5px;
}

.appmenu-search-entry-icon {
    icon-size: 1em;
    color: #2b2b2b;
}

#appmenu-search-entry StLabel.hint-text {
    color: rgba(70, 70, 70, 0.3);
}

/* ===================================================================
 * Window list applet (window-list@cinnamon.org/applet.js)
 * ===================================================================*/
.window-list-box {
    spacing: 3px;
    padding-left: 0px;
}

.window-list-box.vertical {
    padding-left: 0px;
    padding-right: 0px;
    padding-top: 10px;
    padding-bottom: 10px;
}

.window-list-item-label {
    width: 15em;
    min-width: 5px;
}

.window-list-item-box {
    font-weight: bold;
    color: rgb(62, 62, 62);
    padding-top: 1px;
    padding-left: 4px;
    padding-right: 4px;
    border-image: url("panel-assets/hover-3.svg") 6;
}

.panel-top .window-list-item-box {
    border-image: url("panel-assets/hover-3-top.svg") 6;
}

.panel-left .window-list-item-box {
    padding-left: 0px;
    padding-right: 0px;
    border-image: url("panel-assets/hover-3-left.svg") 6;
}

.panel-right .window-list-item-box {
    padding-left: 0px;
    padding-right: 0px;
    border-image: url("panel-assets/hover-3-right.svg") 6;
}

.window-list-item-box:hover {
    border-image: url("panel-assets/hover-1.svg") 6;
}

.panel-top .window-list-item-box:hover {
    border-image: url("panel-assets/hover-1-top.svg") 6;
}

.panel-left .window-list-item-box:hover {
    border-image: url("panel-assets/hover-1-left.svg") 6;
}

.panel-right .window-list-item-box:hover {
    border-image: url("panel-assets/hover-1-right.svg") 6;
}

.window-list-item-box:active,
.window-list-item-box:checked,
.window-list-item-box:focus,
.window-list-item-box:checked:hover,
.window-list-item-box:focus:hover,
.window-list-item-box:active:hover {
    font-weight: bold;
    color: #fff;
    border-image: url("panel-assets/pressed.svg") 6;
}

.panel-top .window-list-item-box:active,
.panel-top .window-list-item-box:checked,
.panel-top .window-list-item-box:focus,
.panel-top .window-list-item-box:checked:hover,
.panel-top .window-list-item-box:focus:hover,
.panel-top .window-list-item-box:active:hover {
    border-image: url("panel-assets/pressed-top.svg") 6;
}

.panel-left .window-list-item-box:active,
.panel-left .window-list-item-box:checked,
.panel-left .window-list-item-box:focus,
.panel-left .window-list-item-box:checked:hover,
.panel-left .window-list-item-box:focus:hover,
.panel-left .window-list-item-box:active:hover {
    border-image: url("panel-assets/pressed-left.svg") 6;
}

.panel-right .window-list-item-box:active,
.panel-right .window-list-item-box:checked,
.panel-right .window-list-item-box:focus,
.panel-right .window-list-item-box:checked:hover,
.panel-right .window-list-item-box:focus:hover,
.panel-right .window-list-item-box:active:hover {
    border-image: url("panel-assets/pressed-right.svg") 6;
}

.window-list-item-demands-attention {
    border-image: url("panel-assets/attention.svg") 6;
}

.panel-top .window-list-item-demands-attention {
    border-image: url("panel-assets/attention-top.svg") 6;
}

.panel-left .window-list-item-demands-attention {
    border-image: url("panel-assets/attention-left.svg") 6;
}

.panel-right .window-list-item-demands-attention {
    border-image: url("panel-assets/attention-right.svg") 6;
}

.window-list-item-box .progress {
    border-image: url("panel-assets/progress.svg") 6;
}

.panel-top .window-list-item-box .progress {
    border-image: url("panel-assets/progress-top.svg") 6;
}

.panel-left .window-list-item-box .progress {
    border-image: url("panel-assets/progress-left.svg") 6;
}

.panel-right .window-list-item-box .progress {
    border-image: url("panel-assets/progress-right.svg") 6;
}

.window-list-preview {
    border-image: url("background-assets/bg-1.png") 6;
    color: rgb(70, 70, 70);
    padding: 6px 12px 12px 12px;
    font-size: 1em;
    font-weight: bold;
    text-shadow: white 0px 0px 2px;
}

/* ===================================================================
 * Grouped window list (grouped-window-list@cinnamon.org)
 * ===================================================================*/

.grouped-window-list-thumbnail-label {
    padding-left: 4px;
}
.grouped-window-list-number-label {
    font-size: 12px;
    color: #d6d6d6;
}
.grouped-window-list-badge {
    border-radius: 99px;
    background-color: #4a4a4a;
}
.grouped-window-list-button-label {
    padding-left: 4px;
}
.grouped-window-list-thumbnail-alert {
    background: rgba(255,52,52,0.3);
}

.grouped-window-list-item-box {
    text-align: left;
    font-weight: bold;
    color: rgb(62, 62, 62);
    padding-top: 1px;
    padding-left: 4px;
    padding-right: 4px;
    border-image: none;
}

.panel-top .grouped-window-list-item-box {
    border-image: url("panel-assets/hover-3-top.svg") 6;
}

.panel-left .grouped-window-list-item-box {
    padding-left: 0px;
    padding-right: 0px;
    border-image: url("panel-assets/hover-3-left.svg") 6;
}

.panel-right .grouped-window-list-item-box {
    padding-left: 0px;
    padding-right: 0px;
    border-image: url("panel-assets/hover-3-right.svg") 6;
}

.grouped-window-list-item-box:active,
.grouped-window-list-item-box:active:hover,
.grouped-window-list-item-box:checked,
.grouped-window-list-item-box:checked:hover,
.grouped-window-list-item-box:hover {
    border-image: url("panel-assets/hover-1.svg") 6;
}

.panel-top .grouped-window-list-item-box:hover {
    border-image: url("panel-assets/hover-1-top.svg") 6;
}

.panel-left .grouped-window-list-item-box:hover {
    border-image: url("panel-assets/hover-1-left.svg") 6;
}

.panel-right .grouped-window-list-item-box:hover {
    border-image: url("panel-assets/hover-1-right.svg") 6;
}

.grouped-window-list-item-box:focus,
.grouped-window-list-item-box:focus:hover,
.grouped-window-list-item-box:focus:active:hover {
    font-weight: bold;
    color: #fff;
    border-image: url("panel-assets/pressed.svg") 6;
}

.panel-top .grouped-window-list-item-box:focus,
.panel-top .grouped-window-list-item-box:focus:hover,
.panel-top .grouped-window-list-item-box:focus:active:hover {
    border-image: url("panel-assets/pressed-top.svg") 6;
}

.panel-left .grouped-window-list-item-box:focus,
.panel-left .grouped-window-list-item-box:focus:hover,
.panel-left .grouped-window-list-item-box:focus:active:hover {
    border-image: url("panel-assets/pressed-left.svg") 6;
}

.panel-right .grouped-window-list-item-box:focus,
.panel-right .grouped-window-list-item-box:focus:hover,
.panel-right .grouped-window-list-item-box:focus:active:hover {
    border-image: url("panel-assets/pressed-right.svg") 6;
}

.grouped-window-list-item-demands-attention {
    border-image: url("panel-assets/attention.svg") 6;
}

.panel-top .grouped-window-list-item-demands-attention {
    border-image: url("panel-assets/attention-top.svg") 6;
}

.panel-left .grouped-window-list-item-demands-attention {
    border-image: url("panel-assets/attention-left.svg") 6;
}

.panel-right .grouped-window-list-item-demands-attention {
    border-image: url("panel-assets/attention-right.svg") 6;
}

.grouped-window-list-item-box .progress {
    border-image: url("panel-assets/progress.svg") 6;
}

.panel-top .grouped-window-list-item-box .progress {
    border-image: url("panel-assets/progress-top.svg") 6;
}

.panel-left .grouped-window-list-item-box .progress {
    border-image: url("panel-assets/progress-left.svg") 6;
}

.panel-right .grouped-window-list-item-box .progress {
    border-image: url("panel-assets/progress-right.svg") 6;
}

.grouped-window-list-thumbnail-menu {
    border-image: url("background-assets/bg-1.png") 6;
    color: rgb(70, 70, 70);
    padding: 0px;
    font-size: 0.9em;
    font-weight: bold;
}

.grouped-window-list-thumbnail-menu .item-box {
    padding: 10px;
    border: 1px solid rgba(0, 0, 0, 0);
    border-radius: 0px;
    spacing: 4px;
}

.grouped-window-list-thumbnail-menu .item-box:outlined {
    padding: 6px;
    border: 2px solid rgba(85, 85, 85, 0);
}

.grouped-window-list-thumbnail-menu .item-box:selected {
    border-image: url("misc-assets/hover-2.png") 6;
    color: #fff;
}

.grouped-window-list-thumbnail-menu .thumbnail {
    width: 256px;
}

.grouped-window-list-thumbnail-menu .separator {
    width: 1px;
    background: rgba(255, 255, 255, 0.33);
}

/* ===================================================================
 * Sound applet (sound@cinnamon.org/applet.js)
 * ===================================================================*/
.sound-player StButton {
    width: 22px;
    height: 22px;
    padding: 5px;
    color: #464646;
}

.sound-player StButton:small {
    border: 1px solid transparent;
    border-radius: 3px;
    width: 16px;
    height: 16px;
}

.sound-player StButton:hover,
.sound-player StButton:active {
    color: rgba(70, 70, 70, 0.4);
}

.sound-player StButton:small:hover {
    color: rgb(70, 70, 70);
    border-image: url("button-assets/button-hover.png") 4;
}

.sound-player StButton:small:active {
    color: rgb(70, 70, 70);
    border-image: url("button-assets/button-pressed.png") 4;
}

.sound-player .slider {
    height: 0.5em;
    -slider-height: 0.5em;
    -slider-background-color: #7a7a7a;
    -slider-border-color: rgba(0, 0, 0, 0);
    -slider-active-background-color: #accd8a;
    -slider-active-border-color: rgba(0, 0, 0, 0);
    -slider-border-width: 0px;
    -slider-handle-radius: 0px;
}

.sound-player StBoxLayout {
    spacing: 0.5em;
}

.sound-player > StBoxLayout {
    padding: 0 16px 8px;
}

.sound-player > StBoxLayout:first-child {
    border: 1px solid #c2c2c2;
    border-top: 0;
    border-right: 0;
    border-left: 0;
}

.sound-player-overlay {
    border-top: 1px solid #c2c2c2;
    width: 300px;
    padding: 16px;
    spacing: 0.5em;
    color: #464646;
    background: #ececec;
}

.sound-player-overlay StBoxLayout {
    padding-top: 2px;
}

.sound-player-generic-coverart {
    background: rgba(0, 0, 0, 0.2);
}

/* ===================================================================
 * Workspace Switcher applet (workspace-switcher@cinnamon.org/applet.js)
 * ===================================================================*/
.workspace-button {
    width: 20px;
    height: 6px;
    color: rgb(70, 70, 70);
    border: 0px;
    border-color: rgba(200, 200, 200, 1);
    padding: 3px;
    padding-right: 1px;
    font-weight: bold;
    padding-top: 5px;
}

.workspace-button.vertical {
    padding: 0px;
    height: 1.5em;
}

.workspace-button:hover {
    border-image: url("panel-assets/hover-1.svg") 6;
    color: rgb(70, 70, 70);
    border-color: rgba(200, 200, 200, 1);
}

.panel-top .workspace-button:hover {
    border-image: url("panel-assets/hover-1-top.svg") 6;
}

.panel-left .workspace-button:hover {
    border-image: url("panel-assets/hover-1-left.svg") 6;
}

.panel-right .workspace-button:hover {
    border-image: url("panel-assets/hover-1-right.svg") 6;
}

.workspace-button:outlined {
    border-image: url("panel-assets/pressed.svg") 6;
    background: rgba(200, 200, 200, 1);
    color: #fff;
}

.panel-top .workspace-button:outlined {
    border-image: url("panel-assets/pressed-top.svg") 6;
}

.panel-left .workspace-button:outlined {
    border-image: url("panel-assets/pressed-left.svg") 6;
}

.panel-right .workspace-button:outlined {
    border-image: url("panel-assets/pressed-right.svg") 6;
}

/* Controls the style when using the "Visual representation" option */
.workspace-graph {
    padding: 3px 4px 3px 4px;
    spacing: 4px;
}

.workspace-graph .workspace {
    border: 1px solid #111;
    background-gradient-direction: vertical;
    background-gradient-start: #444;
    background-gradient-end: #5d5d5d;
}

.workspace-graph .workspace:active {
    border: 1px solid #ccc;
    background-gradient-direction: vertical;
    background-gradient-start: #333;
    background-gradient-end: #5d5d5d;
}

.workspace-graph .workspace .windows {
    -active-window-background: rgba(140, 140, 140, 1.0);
    -active-window-border: rgba(0, 0, 0, 0.7);
    -inactive-window-background: rgba(140, 140, 140, 1.0);
    -inactive-window-border: rgba(0, 0, 0, 0.7);
}

.workspace-graph .workspace:active .windows {
    -active-window-background: rgba(172, 205, 138, 1.0);
    -active-window-border: rgba(0, 0, 0, 0.9);
    -inactive-window-background: rgba(170, 170, 170, 1.0);
    -inactive-window-border: rgba(0, 0, 0, 0.7);
}

/* ===================================================================
 * Panel Launchers applet (panel-launchers@cinnamon.org/applet.js)
 * ===================================================================*/
.panel-launchers {
    spacing: 0;
}

.panel-launchers .launcher {
    border: 1px solid transparent;
    padding-left: 2px;
    padding-right: 2px;
}

.panel-left .panel-launchers .launcher,
.panel-right .panel-launchers .launcher {
    padding: 0;
    padding-top: 2px;
    padding-bottom: 2px;
}

.panel-launchers .launcher:hover {
    border-image: url("panel-assets/hover-1.svg") 6;
}

.panel-top .panel-launchers .launcher:hover {
    border-image: url("panel-assets/hover-1-top.svg") 6;
}

.panel-left .panel-launchers .launcher:hover {
    border-image: url("panel-assets/hover-1-left.svg") 6;
}

.panel-right .panel-launchers .launcher:hover {
    border-image: url("panel-assets/hover-1-right.svg") 6;
}

/* ===================================================================
 * Applets (applet.js)
 * ===================================================================*/
.applet-separator {
    border-image: url("panel-assets/separator.png") 4 5 0 2 stretch;
    padding: 5px 4px;
}

.applet-separator-line {
}

.applet-box {
    font-weight: bold;
    color: rgb(74, 74, 74);
    padding-left: 4px;
    padding-right: 4px;
    padding-top: 1px;
    spacing: 3px;
    text-align: center;
}

.applet-box.vertical {
    padding: 0;
    padding-top: 5px;
    padding-bottom: 5px;
}

.applet-box:checked,
.applet-box:hover {
    border-image: url("panel-assets/hover-1.svg") 6;
}

.panel-top .applet-box:checked,
.panel-top .applet-box:hover {
    border-image: url("panel-assets/hover-1-top.svg") 6;
}

.panel-left .applet-box:checked,
.panel-left .applet-box:hover {
    border-image: url("panel-assets/hover-1-left.svg") 6;
}

.panel-right .applet-box:checked,
.panel-right .applet-box:hover {
    border-image: url("panel-assets/hover-1-right.svg") 6;
}

.applet-box:highlight {
    background-color: #accd8a;
}

.applet-box:active {
}

.applet-label {
    font-weight: bold;
    color: rgb(66, 66, 66);
}

.applet-label:checked,
.applet-label:hover {
    font-weight: bold;
}

.applet-icon {
    icon-size: 22px;
}

.applet-icon:hover,
.applet-icon:checked,
.applet-box:checked > .applet-icon,
.applet-box:hover > .applet-icon {
}

/* ===================================================================
 * Workspace OSD (windowManager.js)
 * ===================================================================*/

.expo-workspaces-name-entry {
    border-image: url("misc-assets/expo-name-entry.png") 6;
    padding: 8px 12px;
    border-radius: 2px;
    height: 1.5em;
    color: rgba(255, 255, 255, 0.7);
    text-align: center;
    font-weight: bold;
    selected-color: #fff;
    caret-color: #fff;
    caret-size: 1px;
    selection-background-color: #accd8a;
    transition-duration: 150;
}

.expo-workspaces-name-entry#selected {
    color: rgba(255, 255, 255, 1);
    transition-duration: 150;
}

.expo-workspaces-name-entry#selected:focus {
    color: rgba(255, 255, 255, 1);
    transition-duration: 150;
}

.expo-workspaces-name-entry:focus {
    color: rgba(255, 255, 255, 1);
    transition-duration: 150;
}

/* ===================================================================
 * Notification applet (notifications@cinnamon.org/applet.js)
 * ===================================================================*/
.notification-applet-padding {
    padding: .5em 1em;
}

.notification-applet-container {
    max-height: 100px;
}

/* Check Boxes */
.check-box CinnamonGenericContainer {
    spacing: .2em;
    min-height: 18px;
    padding-top: 2px;
}

.check-box StBin,
.check-box:focus StBin,
.check-box-2 StBin,
.check-box-2:focus StBin {
    width: 16px;
    height: 16px;
    background-image: url("control-assets/checkbox-unchecked.png");
}

.check-box:checked StBin,
.check-box:focus:checked StBin,
.check-box-2:checked StBin,
.check-box-2:focus:checked StBin {
    background-image: url("control-assets/checkbox-checked.png");
}

.check-box StLabel {
    font-weight: normal;
}

.radiobutton CinnamonGenericContainer {
    spacing: .2em;
    height: 18px;
    padding-top: 2px;
}

.radiobutton StBin,
.radiobutton:focus StBin {
    width: 16px;
    height: 16px;
    background-image: url("control-assets/radio-unselected.png");
}

.radiobutton:checked StBin,
.radiobutton:focus:checked StBin {
    background-image: url("control-assets/radio-selected.png");
}

.radiobutton StLabel {
    padding-top: 4px;
    font-size: 0.9em;
    box-shadow: none;
}

.flashspot {
    background-color: white;
}

/* ===================================================================
 * User applet (user@cinnamon.org/applet.js)
 * ===================================================================*/
.user-icon {
    border: 1px solid transparent;
    border-radius: 99px;
}

.user-label {
    color: rgb(70, 70, 70);
    font-size: 1.6em;
    margin: 6px;
}

.user-widget.vertical {
  spacing: 10px;
}

.user-widget.vertical .user-widget-label {
  color: rgb(70, 70, 70);
  text-align: center;
  font-size: 1.2em;
}

.user-icon StIcon {
  padding: 12px;
  border: 1px solid transparent;
  border-radius: 99px;
}

.user-icon.user-avatar {
  border: transparent;
  border-radius: 99px;
}

.user-icon StIcon.highlighted {
  border: 1px solid rgb(192, 192, 192);
  border-radius: 99px;
}

/* ===================================================================
 * OSD Popups
 * ===================================================================*/
.info-osd {
    font-size: 1em;
    border-image: url("background-assets/bg-1.png") 6;
    padding: 12px;
    color: rgb(70, 70, 70);
    text-align: center;
}

.restart-osd {
    font-size: 1.6em;
}

.workspace-osd {
    border-image: url("background-assets/bg-1.png") 6;
    padding: 9px 15px;
    color: rgb(70, 70, 70);
    font-weight: bold;
    font-size: 4em;
}

.media-keys-osd {
    border-image: url("background-assets/bg-1.png") 6;
    color: rgb(70, 70, 70);
    margin-bottom: 1em;
    padding: 20px;
    spacing: 1em;
}

.media-keys-osd .level {
    min-width: 160px;
    -barlevel-height: 0.7em;
    -barlevel-background-color: rgba(70, 70, 70, 0.4);
    -barlevel-active-background-color: rgb(172, 205, 138);
    -barlevel-amplify-color: rgb(172, 205, 138);
    border-radius: 0.3em;
}

.media-keys-osd .level-bar {
    border-radius: 0.3em;
    background-color: rgb(172, 205, 138);
}

/* ===================================================================
 * Snap/Tile Chrome (windowManager.js)
 * ===================================================================*/
.tile-preview,
.tile-hud {
    background-color: rgba(172, 205, 138, 0.4);
    border: 1px solid rgba(172, 205, 138, 0.8);
}

.tile-preview.snap,
.tile-hud.snap {
    background-color: rgba(172, 205, 138, 0.8);
}

.tile-hud:top {
    border-top-width: 0px;
    border-radius: 0px 0px 8px 8px;
}

.tile-hud:bottom {
    border-bottom-width: 0px;
    border-radius: 8px 8px 0px 0px;
}

.tile-hud:left {
    border-left-width: 0px;
    border-radius: 0px 8px 8px 0px;
}

.tile-hud:right {
    border-right-width: 0px;
    border-radius: 8px 0px 0px 8px;
}

.tile-hud:top-left {
    border-top-width: 0px;
    border-left-width: 0px;
    border-radius: 0px 0px 8px 0px;
}

.tile-hud:top-right {
    border-top-width: 0px;
    border-right-width: 0px;
    border-radius: 0px 0px 0px 8px;
}

.tile-hud:bottom-left {
    border-bottom-width: 0px;
    border-left-width: 0px;
    border-radius: 0px 8px 0px 0px;
}

.tile-hud:bottom-right {
    border-bottom-width: 0px;
    border-right-width: 0px;
    border-radius: 8px 0px 0px 0px;
}
