$opposite:              null; // white for dark and vice versa
$base_color:            null;
$text_color:            null;
$bg_color:              null;
$borders_color:         null;
$separator_color:       null;
$header_bg:             null;
$header_bg_backdrop:    null;
$header_border:         null;
$header_highlight:      null;
$osd_bg_color:          null;
$entry_border:          null;
$fg_color:              null;
$header_entry_bg:       null;
$header_entry_border:   null;
$button_bg:             null;
$insensitive_bg_color:  null;
$header_button_bg:      null;
$header_button_border:  null;
$trough_color_treeview: null;
$trough_color:          null;
$wm_title_unfocused:    null;
$wm_button_hover_bg:    null;
$wm_button_active_bg:   null;
$wm_icon_bg:            null;
$wm_icon_unfocused_bg:  null;
$wm_icon_hover_bg:      null;

@if $variant == 'light' {
    // Light Variant Colors
    $opposite:              BLACK;
    $base_color:            #FFFFFF;
    $text_color:            #303030;
    $header_bg:             #EBEBED;
    $bg_color:              lighten($header_bg, 5%);
    $borders_color:         darken($bg_color, 18%);
    $separator_color:       #DFDFDF;
    $header_bg_backdrop:    lighten($header_bg, 3%);
    $header_border:         #BDBDBD;
    $header_highlight:      #EEEEEE;
    $osd_bg_color:          #404040;
    $entry_border:          #BABABA;
    $fg_color:              transparentize($opposite, 0.13);
    $header_entry_bg:       transparentize($base_color, 0.1);
    $header_entry_border:   transparentize($fg_color, 0.7);
    $button_bg:             lighten($bg_color, 2%);
    $insensitive_bg_color:  mix($bg_color, $base_color, 40%);
    $header_button_bg:      transparentize($button_bg, 0.1);
    $header_button_border:  transparentize($fg_color, 0.7);
    $trough_color_treeview: #D9D9D9;
    $trough_color:          #FFFFFF;
    $wm_title_unfocused:    #9D9D9F;
    $wm_button_hover_bg:    #FDFDFF;
    $wm_button_active_bg:   #909092;
    $wm_icon_bg:            #404040;
    $wm_icon_unfocused_bg:  #B6B6B8;
    $wm_icon_hover_bg:      #404040;
} @else {
    // Dark Variant Colors
    $opposite:              WHITE;
    $base_color:            #333339;
    $text_color:            #DADADA;
    $header_bg:             #222226;
    $bg_color:              lighten($header_bg, 5%);
    $borders_color:         darken($bg_color,6%);
    $separator_color:       darken($bg_color, 6%);
    $header_bg_backdrop:    lighten($header_bg, 1.5%);
    $header_border:         darken($header_bg, 4%);
    $header_highlight:      #373737;
    $osd_bg_color:          #353535;
    $entry_border:          $borders_color;
    $fg_color:              transparentize($opposite, 0.13);
    $header_entry_bg:       transparentize(lighten($header_bg, 22%), 0.6);
    $header_entry_border:   transparentize(darken($header_bg, 12%), 0.6);
    $button_bg:             lighten($base_color, 2%);
    $insensitive_bg_color:  lighten($bg_color, 2%);
    $header_button_bg:      transparentize(lighten($header_bg, 22%), 0.6);
    $header_button_border:  transparentize(darken($header_bg, 12%), 0.6);
    $trough_color_treeview: darken($bg_color, 5%);
    $trough_color:          darken($bg_color, 5%);
    $wm_title_unfocused:    #A7A7AB;
    $wm_button_hover_bg:    #4C4C50;
    $wm_button_active_bg:   #949498;
    $wm_icon_bg:            #909090;
    $wm_icon_unfocused_bg:  #555559;
    $wm_icon_hover_bg:      #C4C7CC;
}

// FG colors
$header_fg:                 $fg_color;
$dark_sidebar_fg:           $fg_color;
$insensitive_fg_color:      transparentize($fg_color, 0.45);
$dim_label_fg_color:        transparentize($fg_color, 0.35);
$osd_fg_color:              #DBDBDB;
$osd_insensitive_fg_color:  mix($osd_fg_color, opacify($osd_bg_color, 1), 30%);

// BG colors
$entry_bg:                  $base_color;
$menu_selected_bg_color:    transparentize($opposite, 0.9);
$filechooser_bg:            $header_bg;
$osd_button_bg:             transparentize(lighten($osd_bg_color, 22%), 0.6);
$osd_entry_bg:              transparentize(lighten($osd_bg_color, 22%), 0.6);
$osd_insensitive_bg_color:  darken($osd_bg_color, 3%);
$button_active_bg:          transparentize(black, 0.85);
$wm_icon_close_bg:          #F8F8F8;
$wm_icon_active_bg:         #FFFFFF;
$dark_sidebar_bg:           darken($bg_color, 1%);

// Borders
$dark_sidebar_border: $borders_color;
$osd_button_border: transparentize(darken($osd_bg_color, 12%), 0.6);
$osd_entry_border: transparentize(darken($osd_bg_color, 12%), 0.6);
$osd_borders_color: transparentize(black, 0.3);
$button_border: $borders_color;
$button_active_border: darken($button_border, 10%);
$header_border_unfocused: lighten($header_border, 5%);

// Accents
$accent_color: #35A854;
$selected_bg_color: $accent_color;
$selected_fg_color: #FFFFFF;
$selected_borders_color: darken($selected_bg_color, 15%);
$wm_button_close_bg: $selected_bg_color;
$wm_button_close_hover_bg: lighten($selected_bg_color, 14%);
$wm_button_close_active_bg: darken($selected_bg_color, 20%);
$tooltip_bg_color: transparentize(mix($selected_bg_color, black, 95%), 0.05);
$tooltip_fg_color: #FFFFFF;
$drop_target_color: $selected_bg_color;

// Links and status
$link_color: #5294E2;
$link_visited_color: #5294E2;
$warning_color: #F27835;
$warning_fg_color: WHITE;
$error_color: #FC4138;
$error_fg_color: WHITE;
$success_color: #73D216;
$destructive_color: #F04A50;
$suggested_color: #6DB442;
$question_color: #55C1EC;

// Panel (MATE/Xfce)
$panel_bg: #2F2F2F;
$panel_fg: #DADADA;

// Apps
$terminal_bg: #222226;
